Vue.component('scanner',{
    name:'scanner',
    template:`
    <div> 
        <div>
            <el-select v-model="scan_name" placeholder="请选择扫描仪">
                <el-option
                    v-for="item in scanner_list"
                    :key="item"
                    :label="item"
                    :value="item"
                >
                </el-option>
            </el-select>
            <el-button-group>
                <el-button type="primary" @click="onGetScannerClickHandle" v-show="get_visible">获取扫描仪</el-button>
                <el-button type="primary" @click="onOpenClickHandle" v-show="open_visible">打开扫描仪</el-button>
                <el-button type="primary" @click="onScanClickHandle" v-show="scan_visible">扫描</el-button>
                <el-button type="primary" @click="onCloseClickHandle" v-show="close_visible">关闭扫描仪</el-button>
                <el-button type="primary" @click="onSetClickHandle" v-show="set_visible">设置参数</el-button>
                <el-button type="primary" @click="onClearClickHandle">清空信息</el-button>
            </el-button-group>
            <div>
                <el-image
                    v-for="url in image_list"
                    style="margin:10px;width: 100px; height: 100px" :src="url" :preview-src-list="image_list">
                </el-image>
            </div>
        </div>       
        <el-dialog
          title="参数设置"
          :visible.sync="dialogVisible"
          width="30%">
          <el-form :model="scanParamsForm" ref="scanParamsForm">
            <el-form-item
              v-for="(domain, index) in scanParamsForm.domains"
              :label="domain.title"
              :key="domain.name"
              :prop="'domains.' + index + '.value'"
            >
              <el-tooltip class="item" effect="dark" :content="domain.desc" placement="top-start">
                <el-input v-model="domain.value" v-if="domain.isInput" :type="domain.input_type"></el-input>
                <el-select v-model="domain.value" v-if="domain.isSelect">
                  <el-option v-for="item in domain.constraint" :key="item" :label="item" :value="item"></el-option>
                </el-select>
                <el-radio-group v-model="domain.value" v-if="domain.isRadio">
                  <el-radio :label="true">是</el-radio>
                  <el-radio :label="false">否</el-radio>
                </el-radio-group>
              </el-tooltip>
            </el-form-item>
          </el-form>
          <template #footer>
            <span class="dialog-footer">
              <el-button @click="dialogVisible = false">取 消</el-button>
              <el-button type="primary" @click="onSetParamsClickHandle">确 定</el-button>
            </span>
          </template>
        </el-dialog>
    </div>`,
    props:{
        nko_api:null
    },
    data(){
        return{
          scanParamsForm: {
                domains: []
              },
              get_visible:true,
              open_visible:false,
              scan_visible:false,
              close_visible:false,
              set_visible:false,
              image_list:[],
              scanner_list:[],
              scan_name:'',
              dialogVisible:false
        }
    },
    methods:{
        async onGetScannerClickHandle(){
            let ret = await this.nko_api.GetScannerList();
            if(ret){
                if(ret.length==0){
                    this.$message("未连接扫描仪");
                    return;
                }
                this.scanner_list = ret;
                this.scan_name = this.scanner_list[0];
                this.open_visible = true;
            }else{
                this.$message("errcode:"+this.nko_api.retData.retcode+",msg:"+this.nko_api.retData.retinfo);
            }
        },
        async onOpenClickHandle(){
            if(this.scan_name==""){
                return;
            }
            let ret = await this.nko_api.OpenScanner(this.scan_name);
            if(ret){
                this.$message("打开扫描仪成功");
                this.scan_visible = true;
                this.set_visible = true;
                this.close_visible = true;
                this.open_visible = false;
            }else{
                this.$message("errcode:"+this.nko_api.retData.retcode+",msg:"+this.nko_api.retData.retinfo);
            }
        },
        async onScanClickHandle(){
            const rLoading = this.openLoading();
            let ret = await this.nko_api.StartScan();
            if(ret){
              rLoading.close();
              this.image_list = [];
              for(var i=0;i<ret.length;i++){
                  let path = ret[i].replace(/\\/g,"/");
                  this.image_list.push("file:///"+path);
              }
            }else{
              rLoading.close();
              this.$message("errcode:"+this.nko_api.retData.retcode+",msg:"+this.nko_api.retData.retinfo);
            }
            
        },
        async onCloseClickHandle(){
            this.nko_api.CloseScanner();
            this.scan_visible = false;
            this.set_visible = false;
            this.close_visible = false;
            this.open_visible = true;
        },
        async onClearClickHandle(){
            this.image_list.splice(0,this.image_list.length);
        },
        async onSetClickHandle(){
          const rLoading = this.openLoading();
            let ret = await this.nko_api.GetScanParamList();    
            if(ret){
              let param_values = await this.nko_api.GetScanParams(ret);
              if(param_values){
                this.scanParamsForm.domains = [];
                for(let i=0;i<ret.length;i++){
                    ret[i].value = param_values[i].value;
                    if(ret[i].read_only){
                      continue;
                    }
                    if(ret[i].type=="bool"){
                      ret[i].isInput = false;
                      ret[i].isSelect = false;
                      ret[i].isRadio = true;
                    }else if(ret[i].constraint_type=="word_list" || ret[i].constraint_type=="string_list"){
                      ret[i].isInput = false; 
                      ret[i].isSelect = true;
                      ret[i].isRadio = false; 
                    }else{
                      ret[i].isInput = true; 
                      ret[i].isSelect = false;  
                      ret[i].isRadio = false; 
                    }
                    if(ret[i].type=="int" || ret[i].type=="float"){
                      ret[i].input_type = "number";
                    }else{
                      ret[i].input_type = "text"; 
                    }
                    ret[i].old_value = ret[i].value;
                    this.scanParamsForm.domains.push(ret[i]);
                }
                rLoading.close();
                this.dialogVisible = true;
              }else{
                rLoading.close();
                this.$message("errcode:"+this.nko_api.retData.retcode+",msg:"+this.nko_api.retData.retinfo);
              }
            }else{
              rLoading.close();
              this.$message("errcode:"+this.nko_api.retData.retcode+",msg:"+this.nko_api.retData.retinfo);
            }
        },
        async onSetParamsClickHandle() {
          let params = [];
          for(let i=0;i<this.scanParamsForm.domains.length;i++){
            if(this.scanParamsForm.domains[i].value!=this.scanParamsForm.domains[i].old_value){
              let val = this.scanParamsForm.domains[i].value;
              if(this.scanParamsForm.domains[i].type=="float" || this.scanParamsForm.domains[i].type=="int"){
                  val = Number(val);
              }
              params.push({
                name:this.scanParamsForm.domains[i].name,
                value:val
              });
            }
          }
          s = JSON.stringify(params);
          alert(s);
          let ret = await this.nko_api.SetScanParams(params);
          if(ret){
            this.$message("设置成功");
            this.dialogVisible = false;
          }else{
            alert("errcode:"+this.nko_api.retData.retcode+",msg:"+this.nko_api.retData.retinfo);
          }             
        }
    }
}) 